
#########summarySE function#########
summarySE <- function(data=NULL, measurevar, groupvars=NULL, na.rm=FALSE,
                      conf.interval=.95, .drop=TRUE) {
  library(plyr)
  
  # New version of length which can handle NA's: if na.rm==T, don't count them
  length2 <- function (x, na.rm=FALSE) {
    if (na.rm) sum(!is.na(x))
    else       length(x)
  }
  
  # This does the summary. For each group's data frame, return a vector with
  # N, mean, and sd
  datac <- ddply(data, groupvars, .drop=.drop,
                 .fun = function(xx, col) {
                   c(N    = length2(xx[[col]], na.rm=na.rm),
                     mean = mean   (xx[[col]], na.rm=na.rm),
                     sd   = sd     (xx[[col]], na.rm=na.rm)
                   )
                 },
                 measurevar
  )
  
  # Rename the "mean" column    
  datac <- rename(datac, c("mean" = measurevar))
  
  datac$se <- datac$sd / sqrt(datac$N)  # Calculate standard error of the mean
  
  # Confidence interval multiplier for standard error
  # Calculate t-statistic for confidence interval: 
  # e.g., if conf.interval is .95, use .975 (above/below), and use df=N-1
  ciMult <- qt(conf.interval/2 + .5, datac$N-1)
  datac$ci <- datac$se * ciMult
  
  return(datac)
}


####################################
GrHs.data<-read.csv(file="/Users/ryokooono/Dropbox/R_codes_datasets/LegumeRhizobiaDataset/LR_Fall_2016_Final.csv")

GrHs.rhizobia <- within(GrHs.rhizobia, N_treatment <- relevel(N_treatment, ref = "none"))
CE3 <- GrHs.rhizobia[which(GrHs.rhizobia$Rhizobia_treatment =="CE3"),]

shapiro.test(CE3$PHB_pg_per_ul)

shapiro.test(log(CE3$PHB_pg_per_ul))

CE3_PHB_lm<-lm(log(CE3$PHB_pg_per_ul)~CE3$N_treatment*CE3$CO2_treatment)

summary(CE3_PHB_lm)
CE3_PHB_aov<-aov(log(CE3$PHB_pg_per_ul)~CE3$N_treatment*CE3$CO2_treatment)



print.xtable(xtable(CE3_PHB_lm), type="html", file="CE3_PHB.html")


summary(CE3_PHB_aov)

CE3_PHB_HSD <- TukeyHSD(x=CE3_PHB_aov)



CE3_PHB.levels <- CE3_PHB_HSD$`CE3$N_treatment:CE3$CO2_treatment`[,4]
CE3_PHB.labels <- data.frame(multcompLetters(CE3_PHB.levels)['Letters'])
CE3_PHB.labels$treatment=rownames(CE3_PHB.labels)
CE3_PHB.labels=CE3_PHB.labels[c(4,1,2,3) , ]



df_CE3 <- summarySE(CE3, measurevar="PHB_pg_per_ul", 
                    groupvars=c("CO2_treatment", "N_treatment"))
# Convert dose to a factor variable
df_CE3$CO2_treatment=as.factor(df_CE3$CO2_treatment)
df_CE3$N_treatment=as.factor(df_CE3$N_treatment)

df_CE3$TukeyLetter <-CE3_PHB.labels$Letters
df_CE3$y <-c(0.12,0.19,0.15,0.19)


df_CE3$N_treatment <- factor(df_CE3$N_treatment, levels = c("none", "5mM"))
df_CE3$x <- c(1.25,0.75,2.25,1.75)


head(df_CE3)

PHB_GH <-ggplot(df_CE3, aes(x = CO2_treatment, y = PHB_pg_per_ul, fill = N_treatment)) +   
  geom_bar(position = position_dodge(), stat="identity", colour="black") +
  geom_errorbar(aes(ymin=PHB_pg_per_ul-se, ymax=PHB_pg_per_ul+se), width=.2,
                position=position_dodge(.9)) + theme_bw() +
  scale_fill_manual(values = c("white","grey"), name = "",
                    labels = c("No nitrate","5 mM nitrate")) +
  theme(axis.text.x=element_text(size=14), axis.text.y=element_text(size=14), 
        legend.text=element_text(size=14), axis.title =element_text(size=14),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        axis.line = element_line(colour = "black"),
        legend.title=element_text(size=14)) +
  xlab(bquote(~CO[2]~  "treatment")) +
  ylab("PHB (pg/cell)") +
  geom_text(size = 4,mapping = aes(x = x, y = y, label = TukeyLetter, fill = NULL)) 



png('/Users/ryokooono/Dropbox/R_figures/LegumeRhizobia/GH_PHB.png', units="in", width=5, height=3, res=300)
PHB_GH
dev.off()


tiff('/Users/ryokooono/Dropbox/R_figures/LegumeRhizobia/GH_PHB.tiff', units="in", width=5, height=3, res=600)
PHB_GH
dev.off()
